@@ -1,5 +1,5 @@
 multiStart <- function(par, fn, gr = NULL, action = c("solve", "optimize"), 
-    method = c(2, 3, 1), control = list(), details = FALSE, ...) 
+    method = c(2, 3, 1), control = list(), quiet=FALSE, details = FALSE, ...) 
     {
     if (is.null(dim(par))) 
         par <- matrix(par, nrow = 1, ncol = length(par))
@@ -12,13 +12,13 @@ multiStart <- function(par, fn, gr = NULL, action = c("solve", "optimize"),
     pmat <- matrix(NA, nrow(par), ncol(par))
 
     for (k in 1:nrow(par)) {
-        cat("Parameter set : ", k, "... \n")
+        if (!quiet) cat("Parameter set : ", k, "... \n")
         if (action == "solve") 
             ans <- try(BBsolve(par[k, ], fn = fn, method = method, 
-                control = control, ...), silent=TRUE)
+                control = control, quiet=quiet, ...), silent=TRUE)
         if (action == "optimize") 
             ans <- try(BBoptim(par[k, ], fn = fn, gr = gr, method = method, 
-                control = control, ...), silent=TRUE)
+                control = control, quiet=quiet, ...), silent=TRUE)
         if (inherits(ans, "try-error")) next
         cvg[k] <- (ans$convergence == 0)
         values[k] <- if (action == "solve") ans$residual else ans$value
