@@ -72,7 +72,8 @@ lo <- rep(0.001,5)
 hi <- c(Inf, Inf, Inf, Inf, 0.999)
 
 p <- c(runif(5,c(0,0.1,0,0.1,0.2),c(2*pi,5,2*pi,5,0.8)))
-system.time(ans.spg <- spg(par=p, fn=vmmix.loglik, y=y, lower=lo, upper=hi, 
+system.time(ans.spg <- spg(par=p, fn=vmmix.loglik, y=y, 
+   lower=lo, upper=hi, 
    control=list(maxit=2500, gtol=1.e-06, M=20, trace=T)))[1]
 ans.opt <- optim(par=p, fn=vmmix.loglik, y=y, method="L-BFGS-B", lower=lo, upper=hi)
 
@@ -83,8 +84,9 @@ Userproject <- function(x, lower, upper, ...) {
        return(x)
        }
 
-ans.spg2 <- spg(par=p, fn=vmmix.loglik, y=y, lower=lo, upper=hi,
-   project=Userproject,
+ans.spg2 <- spg(par=p, fn=vmmix.loglik, y=y, 
+   project="Userproject",
+   projectArgs=list(lower=lo, upper=hi),
    control=list(maxit=2500, gtol=1.e-06, M=20, trace=T))[1]
 
 
